Contributing
============


Here are the steps needed to set up a development and testing environment.

**WARNING**

This app use *git flow* for branching strategy and release management.

Please, change code and submit all pull requests into branch `develop`


Thanks for contributing, and have fun!


